Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2012-04-05 13:13:32 +0400
committerBastien Montagne <montagne29@wanadoo.fr>2012-04-05 13:13:32 +0400
commit2f452250e5e8d4ef35387b240bab00f75b728e1f (patch)
tree6b2358f8ed68ace1e71cef2bf0eff121a06cda24
parent3a3356826142dac6c999ef314d8feb85e2f6aae8 (diff)
Adding turkish (tr_TR) language.
-rw-r--r--source/blender/blenfont/intern/blf_lang.c1
-rw-r--r--source/blender/makesrna/intern/rna_userdef.c3
2 files changed, 3 insertions, 1 deletions
diff --git a/source/blender/blenfont/intern/blf_lang.c b/source/blender/blenfont/intern/blf_lang.c
index 8a4f8818f40..435ca8776bc 100644
--- a/source/blender/blenfont/intern/blf_lang.c
+++ b/source/blender/blenfont/intern/blf_lang.c
@@ -105,6 +105,7 @@ static const char *locales[] = {
"indonesian", "id_ID",
"serbian (latin)", "sr_RS@latin",
"kyrgyz", "ky_KG",
+ "turkish", "tr_TR",
};
void BLF_lang_init(void)
diff --git a/source/blender/makesrna/intern/rna_userdef.c b/source/blender/makesrna/intern/rna_userdef.c
index 0490282f617..a7aa861e07d 100644
--- a/source/blender/makesrna/intern/rna_userdef.c
+++ b/source/blender/makesrna/intern/rna_userdef.c
@@ -2855,7 +2855,7 @@ static void rna_def_userdef_system(BlenderRNA *brna)
/* locale according to http://www.roseindia.net/tutorials/I18N/locales-list.shtml */
/* if you edit here, please also edit the source/blender/blenfont/intern/blf_lang.c 's locales */
/* Note: As this list is in alphabetical order, and not defined order,
* here is the highest define currently in use: 29 (kyrgyz). */
static EnumPropertyItem language_items[] = {
{ 0, "", 0, "Nearly done", ""},
{ 0, "DEFAULT", 0, "Default (Default)", ""},
@@ -2890,6 +2890,7 @@ static void rna_def_userdef_system(BlenderRNA *brna)
{17, "SERBIAN", 0, "Serbian (Српски)", "sr_RS"},
{28, "SERBIAN_LATIN", 0, "Serbian latin (Srpski latinica)", "sr_RS@latin"},
{ 7, "SWEDISH", 0, "Swedish (Svenska)", "sv_SE"},
+ {30, "TURKISH", 0, "Turkish (Türkçe)", "tr_TR"},
{18, "UKRAINIAN", 0, "Ukrainian (Український)", "uk_UA"},
{ 0, NULL, 0, NULL, NULL}};
@@ -2855,7 +2855,7 @@ static void rna_def_userdef_system(BlenderRNA *brna)
/* if you edit here, please also edit the source/blender/blenfont/intern/blf_lang.c 's locales */
/* Note: As this list is in alphabetical order, and not defined order,
- * here is the highest define currently in use: 29 (kyrgyz). */
+ * here is the highest define currently in use: 30 (turkish). */
static EnumPropertyItem language_items[] = {
{ 0, "", 0, "Nearly done", ""},